@@ -1,5 +1,5 @@
 package Treex::Block::W2A::EN::FixTags;
-$Treex::Block::W2A::EN::FixTags::VERSION = '0.13095';
+$Treex::Block::W2A::EN::FixTags::VERSION = '2.20151102';
 use strict;
 use warnings;
 use utf8;
@@ -65,6 +65,10 @@ sub _get_tag {
     return 'RB' if $tag eq 'EX'
             && join( '', map { $_->form } $node->get_root->get_descendants( { ordered => 1 } ) ) =~ /^There.?$/;
 
+
+    # the enities found by a gazeteer list considered being proper nouns
+    return 'NNP' if (defined $node->wild->{gazeteer_entity_id});
+
     return;
 }
 
@@ -80,7 +84,7 @@ Treex::Block::W2A::EN::FixTags - Fixes tags for TectoMT purposes.
 
 =head1 VERSION
 
-version 0.13095
+version 2.20151102
 
 =head1 DESCRIPTION
 
