@@ -1,5 +1,5 @@
 package Treex::Block::W2A::EN::FixTokenization;
-$Treex::Block::W2A::EN::FixTokenization::VERSION = '0.13095';
+$Treex::Block::W2A::EN::FixTokenization::VERSION = '2.20151102';
 use strict;
 use warnings;
 use Moose;
@@ -30,8 +30,10 @@ sub process_atree {
     my $max_length = 3;
     push @forms, map {'dummy'} ( 1 .. $max_length );
 
+    # NB: do not rewrite this cycle to foreach, $i is also changed inside the cycle
+    # (whenever a match is found)
     TOKEN:
-    foreach my $i ( 0 .. $#nodes - 1 ) {
+    for (my $i = 0;  $i < $#nodes; ++$i ) {
 
         # No more needed with SEnglishW_to_SEnglishM::Tokenization
         # "10 th" -> "10th" (one token is better for parser and transfer)
@@ -77,7 +79,7 @@ Treex::Block::W2A::EN::FixTokenization - fix some issues in output of tokenizer
 
 =head1 VERSION
 
-version 0.13095
+version 2.20151102
 
 =head1 DESCRIPTION
 
