@@ -1,5 +1,5 @@
 package Treex::Block::W2A::EN::NormalizeForms;
-$Treex::Block::W2A::EN::NormalizeForms::VERSION = '0.13095';
+$Treex::Block::W2A::EN::NormalizeForms::VERSION = '2.20151102';
 use strict;
 use warnings;
 use utf8;
@@ -19,12 +19,9 @@ sub process_anode {
         }
     }
 
-    $form =~ s/’/'/g;
-    $form =~ s/"/''/g;
-    $form =~ s/“/``/g;
-    $form =~ s/”/''/g;
-    $form =~ s/«/``/g;
-    $form =~ s/»/''/g;
+    $form =~ s/[’´]/'/g;
+    $form =~ s/["”»]/''/g;
+    $form =~ s/[“«]/``/g;
     $form =~ s/—/--/g;
 
     $anode->set_form($form);
@@ -44,7 +41,7 @@ Treex::Block::W2A::EN::NormalizeForms - normalize some wordforms
 
 =head1 VERSION
 
-version 0.13095
+version 2.20151102
 
 =head1 DESCRIPTION
 
