@@ -1,5 +1,5 @@
 package Treex::Block::W2A::EN::Tokenize;
-$Treex::Block::W2A::EN::Tokenize::VERSION = '0.13095';
+$Treex::Block::W2A::EN::Tokenize::VERSION = '2.20151102';
 use strict;
 use warnings;
 use utf8;
@@ -14,11 +14,11 @@ override 'tokenize_sentence' => sub {
     $sentence =~ s/^(.*)$/ $1 /;
 
     # it's, I'm, we'd, we're, you'll, I've, Peter's
-    $sentence =~ s/([\'’])(s|m|d|ll|re|ve|S|M|D|LL|RE|VE)\s/ $1$2 /g;
+    $sentence =~ s/([\'’´])(s|m|d|ll|re|ve|S|M|D|LL|RE|VE)\s/ $1$2 /g;
 
     # don't
-    $sentence =~ s/(n[\'’]t\s)/ $1 /g;
-    $sentence =~ s/(N[\'’]T\s)/ $1 /g;
+    $sentence =~ s/(n[\'’´]t\s)/ $1 /g;
+    $sentence =~ s/(N[\'’´]T\s)/ $1 /g;
 
     # cannot, wanna ...
     $sentence =~ s/ ([Cc])annot / $1an not /g;
@@ -52,7 +52,7 @@ Treex::Block::W2A::EN::Tokenize - rule-based tokenization
 
 =head1 VERSION
 
-version 0.13095
+version 2.20151102
 
 =head1 DESCRIPTION
 
