@@ -1,5 +1,5 @@
 package Treex::Tool::EnglishMorpho::Lemmatizer;
-$Treex::Tool::EnglishMorpho::Lemmatizer::VERSION = '0.13095';
+$Treex::Tool::EnglishMorpho::Lemmatizer::VERSION = '2.20151102';
 use strict;
 use warnings;
 use Moose;
@@ -12,7 +12,7 @@ has 'exceptions_filename' => (
     is       => 'ro',
     init_arg => undef,
     default  => sub {
-        return require_file_from_share('/data/models/lemmatizer/en/exceptions.tsv');
+        return require_file_from_share('data/models/lemmatizer/en/exceptions2014_11_21.tsv');
     },
 );
 
@@ -20,7 +20,7 @@ has 'negation_filename' => (
     is       => 'ro',
     init_arg => undef,
     default  => sub {
-        return require_file_from_share('/data/models/lemmatizer/en/negation');
+        return require_file_from_share('data/models/lemmatizer/en/negation');
     },
 );
 
@@ -302,7 +302,7 @@ Treex::Tool::EnglishMorpho::Lemmatizer - rule based lemmatizer for English
 
 =head1 VERSION
 
-version 0.13095
+version 2.20151102
 
 =head1 SYNOPSIS
 
